@@ -1,6 +1,7 @@
 from .request_utils import get_request_data
 from .imports import makeParams,get_desired_key_values
-from .request_utils import get_request_info
+from .request_utils import extract_request_data
+from .parse_utils import parse_request
 async def async_makeParams(*arg,**kwargs):
    return makeParams(*arg,**kwargs)
 def required_keys(keys,req,defaults=None):
@@ -114,9 +115,9 @@ def get_spec_kwargs(var_types: Dict[str, Dict[str, Any]], args: list = None, **k
     
     return result
 def get_args_jwargs_user_req(req,var_types={}):
-   result = extract_request_data(req)
+   data = extract_request_data(req)
+   data = get_spec_kwargs(var_types, args,**data)
    data = result.get('json', {})
    args = result.get('args', [])
-   username = result.get('user')
-   data = get_spec_kwargs(var_types, data,**data)
-   return data,args,username
+   username = data.get('user')
+   return args, datas, username
